==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelTemplateHeightRequestedEventArgsDescription } from "./ListPanelTemplateHeightRequestedEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a == null) {
                ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.c(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DataRow", "Number:int");
            a.item("DataItemRef", "(w:DataItem,wf:DataItem)DataRef");
            a.item("Height", "Number:double");
        }
        static d(a) {
            ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.b(a);
            a.ad("ListPanelTemplateHeightRequestedEventArgs", () => new ListPanelTemplateHeightRequestedEventArgsDescription());
            a.ac("ListPanelTemplateHeightRequestedEventArgs", ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.$t = markType(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata, 'ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata');
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelTemplateHeightRequestedEventArgsDescription } from "./ListPanelTemplateHeightRequestedEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a == null) {
                ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.c(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DataRow", "Number:int");
            a.item("DataItemRef", "(w:DataItem,wf:DataItem)DataRef");
            a.item("Height", "Number:double");
        }
        static d(a) {
            ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.b(a);
            a.ae("ListPanelTemplateHeightRequestedEventArgs", () => new ListPanelTemplateHeightRequestedEventArgsDescription());
            a.ad("ListPanelTemplateHeightRequestedEventArgs", ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.$t = markType(ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata, 'ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata');
    ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateHeightRequestedEventArgsDescriptionMetadata;
})();
